==> deepin-system-monitor_6.5.28.tar.xz: BUILD/deepin-system-monitor-main/translations/policy/policy_lo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lo">
<context>
	<name>policy</name>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.renice!message" line="0"/>
		<source>Authentication is required to change process priority</source>
		<translation>ການຢືນຢັນຕ້ອງການເພື່ອປ່ອນຄວາມສຳຄັນຂອງຂະບວນການ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.renice!description" line="0"/>
		<source>Renice process</source>
		<translation>ປ່ອນຄວາມສຳຄັນຂອງຂະບວນການ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.kill!message" line="0"/>
		<source>Authentication is required to control other users&apos; processes</source>
		<translation>ການຢືນຢັນຕ້ອງການເພື່ອຄຸ້ມຄອງຂະບວນການຂອງຜູ້ໃຊ້ອື່ນ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.kill!description" line="0"/>
		<source>Kill process</source>
		<translation>ຍິງຂະບວນການ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.systemctl!message" line="0"/>
		<source>Authentication is required to set service startup type</source>
		<translation>ການຢືນຢັນຕ້ອງການເພື່ອຕັ້ງປະເພດການເລີ່ມຕົ້ນຂອງບໍລິການ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.systemctl!description" line="0"/>
		<source>Set service startup type</source>
		<translation>ຕັ້ງປະເພດການເລີ່ມຕົ້ນຂອງບໍລິການ</translation>
	</message>
</context>
</TS>

==> deepin-system-monitor_6.5.36.tar.xz: BUILD/deepin-system-monitor-main/translations/policy/policy_lo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lo">
<context>
	<name>policy</name>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.renice!message" line="0"/>
		<source>Authentication is required to change process priority</source>
		<translation>ການຢືນຢັນຕ້ອງການເພື່ອປ່ອນຄວາມສຳຄັນຂອງຂະບວນການ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.renice!description" line="0"/>
		<source>Renice process</source>
		<translation>ປ່ອນຄວາມສຳຄັນຂອງຂະບວນການ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.kill!message" line="0"/>
		<source>Authentication is required to control other users&apos; processes</source>
		<translation>ການຢືນຢັນຕ້ອງການເພື່ອຄຸ້ມຄອງຂະບວນການຂອງຜູ້ໃຊ້ອື່ນ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.kill!description" line="0"/>
		<source>Kill process</source>
		<translation>ຍິງຂະບວນການ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.systemctl!message" line="0"/>
		<source>Authentication is required to set service startup type</source>
		<translation>ການຢືນຢັນຕ້ອງການເພື່ອຕັ້ງປະເພດການເລີ່ມຕົ້ນຂອງບໍລິການ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.systemctl!description" line="0"/>
		<source>Set service startup type</source>
		<translation>ຕັ້ງປະເພດການເລີ່ມຕົ້ນຂອງບໍລິການ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.logout!message" line="0"/>
		<source>Logging out other users is required to change process priority</source>
		<translation>ຕ້ອງການການຢັ້ງຢືນເພື່ອອອກຈາກລະບົບຜູ້ໃຊ້ອື່ນ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-system-monitor.logout!description" line="0"/>
		<source>Logout other users</source>
		<translation>ອອກຈາກລະບົບຜູ້ໃຊ້ອື່ນ</translation>
	</message>
</context>
</TS>
